@@ -3,8 +3,8 @@
 ;; Copyright (C) 2025 Diogo Doreto
 
 ;; Author: Diogo Doreto <diogo@doreto.com.br>
-;; Package-Version: 20251019.1853
-;; Package-Revision: e270fec575c3
+;; Package-Version: 20260213.2049
+;; Package-Revision: 315cec02dd3c
 ;; Keywords: convenience languages multimedia tools
 ;; Homepage: https://github.com/DiogoDoreto/emacs-tts
 ;; Package-Requires: ((emacs "29.1"))
@@ -67,6 +67,7 @@
 
 ;;; Changelog:
 
+;; - 1.2.1: Force curl to talk to kokoro endpoint over ipv4
 ;; - 1.2.0: Allow the customization of the extension of the generated audio
 ;;          files. Also default to wav.
 ;; - 1.1.0: Write on the minibuffer when Kokoro server has started.
@@ -291,7 +292,7 @@ Call CALLBACK with error or nil when done."
                      ("lang_code" . ,(string (aref tts-kokoro-voice 0)))
                      ("response_format" . ,tts-audio-extension)
                      ("speed" . ,tts-kokoro-speed))))
-         (cmd (list "curl" "-s" "-X" "POST"
+         (cmd (list "curl" "-4" "-s" "-X" "POST"
                     "-H" "Content-Type: application/json"
                     "-d" (encode-coding-string payload 'utf-8)
                     "-o" file speech-url)))
